@@ -6,10 +6,11 @@
 #' @return A `data.frame`
 #'
 #' @export
-#' @family general support functions
-#' @examples \donttest{
+#' @family support functions
+#'
+#' @examplesIf identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 #' df <- list_geobr()
-#'}
+#'
 list_geobr <- function(){
 
 # Get readme.md file
@@ -24,10 +25,14 @@ if (file.exists(tempf) & file.info(tempf)$size != 0) {
   git_url = "https://raw.githubusercontent.com/ipeaGIT/geobr/master/README.md"
 
   # test server connection
-  check_con <- check_connection(git_url)
+  try(silent = TRUE,
+      check_con <- check_connection(git_url)
+      )
   if(is.null(check_con) | isFALSE(check_con)){ return(invisible(NULL)) }
 
-  httr::GET(url= git_url, httr::write_disk(tempf, overwrite = T))
+  try(silent = TRUE,
+      httr::GET(url= git_url, httr::write_disk(tempf, overwrite = T))
+      )
   readme <- readLines(tempf, encoding = "UTF-8")
 }
 
