@@ -12,12 +12,15 @@
 #'
 select_data_type <- function(temp_meta, simplified=NULL){
 
+  if (!is.logical(simplified)) { stop(paste0("Argument 'simplified' needs to be either TRUE or FALSE")) }
+
   if(isTRUE(simplified)){
     temp_meta <- temp_meta[  grepl(pattern="simplified", temp_meta$download_path), ]
   }
-  else if(isFALSE(simplified)){
+
+  if(isFALSE(simplified)){
     temp_meta <- temp_meta[  !(grepl(pattern="simplified", temp_meta$download_path)), ]
-  } else {  stop(paste0("Argument 'simplified' needs to be either TRUE or FALSE")) }
+  }
 
   return(temp_meta)
 }
@@ -40,7 +43,7 @@ select_year_input <- function(temp_meta, y=year){
 
   # invalid input
   else if (y %in% temp_meta$year){ message(paste0("Using year ", y))
-                                  temp_meta <- temp_meta[temp_meta[,2] == y,]
+                                  temp_meta <- subset(temp_meta, year == y)
                                   return(temp_meta) }
 
   # invalid input
@@ -52,9 +55,11 @@ select_year_input <- function(temp_meta, y=year){
 
 #' Select metadata
 #'
-#' @param geography Which geography will be downloaded
-#' @param simplified Logical TRUE or FALSE indicating  whether the function returns the 'original' dataset with high resolution or a dataset with 'simplified' borders (Defaults to TRUE)
-#' @param year Year of the dataset (passed by red_ function)
+#' @param geography Which geography will be downloaded.
+#' @param simplified Logical TRUE or FALSE indicating  whether the function
+#'        returns the 'original' dataset with high resolution or a dataset with
+#'        'simplified' borders (Defaults to TRUE).
+#' @param year Year of the dataset (passed by read_ function).
 #'
 #' @keywords internal
 #' @examples \dontrun{ if (interactive()) {
@@ -86,6 +91,54 @@ select_metadata <- function(geography, year=NULL, simplified=NULL){
 }
 
 
+#' Support function to download metadata internally used in geobr
+#'
+#' @keywords internal
+#' @examples \dontrun{ if (interactive()) {
+#' df <- download_metadata()
+#' }}
+download_metadata <- function(){ # nocov start
+
+  # create tempfile to save metadata
+  tempf <- file.path(tempdir(), "metadata_gpkg.csv")
+
+  # IF metadata has already been successfully downloaded
+  if (file.exists(tempf) & file.info(tempf)$size != 0) {
+
+  } else {
+
+    # TRY 1: download metadata to temp file
+    metadata_link <- 'https://github.com/ipeaGIT/geobr/releases/download/v1.7.0/metadata_1.7.0_gpkg.csv'
+    try( silent = TRUE,
+         httr::GET(url= metadata_link, httr::write_disk(tempf, overwrite = TRUE))
+         )
+
+    # TRY 2: if download failed, try again using backup link
+    if (!file.exists(tempf) | file.info(tempf)$size == 0) {
+      metadata_link <- 'https://www.ipea.gov.br/geobr/metadata/metadata_1.7.0_gpkg.csv'
+      try( silent = TRUE,
+           httr::GET(url= metadata_link, httr::write_disk(tempf, overwrite = TRUE))
+           )
+    }
+
+    # if everything fails, return NULL
+    if (!file.exists(tempf) | file.info(tempf)$size == 0) { return(invisible(NULL)) }
+
+    }
+
+  # read metadata
+  # metadata <- data.table::fread(tempf, stringsAsFactors=FALSE)
+  metadata <- utils::read.csv(tempf, stringsAsFactors=FALSE)
+
+  # check if data was read Ok
+  if (nrow(metadata)==0) {
+    message("A file must have been corrupted during download. Please restart your R session and download the data again.")
+    return(invisible(NULL))
+  }
+
+  return(metadata)
+} # nocov end
+
 
 
 #' Download geopackage to tempdir
@@ -96,7 +149,7 @@ select_metadata <- function(geography, year=NULL, simplified=NULL){
 #'
 download_gpkg <- function(file_url, progress_bar = showProgress){
 
-  if( !(progress_bar %in% c(T, F)) ){ stop("Value to argument 'showProgress' has to be either TRUE or FALSE") }
+  if (!is.logical(progress_bar)) { stop("'showProgress' must be of type 'logical'") }
 
   # get backup links
   filenames <- basename(file_url)
@@ -114,12 +167,15 @@ download_gpkg <- function(file_url, progress_bar = showProgress){
     if (!file.exists(temps) | file.info(temps)$size == 0) {
 
     # test connection with server1
-    check_con <- check_connection(file_url[1], silent = TRUE)
+    try(silent = TRUE,
+        check_con <- check_connection(file_url[1], silent = TRUE)
+        )
 
     # if server1 fails, replace url and test connection with server2
     if (is.null(check_con) | isFALSE(check_con)) {
+#      message('Using Github') # debug
       file_url <- file_url2
-      check_con <- check_connection(file_url[1])
+      check_con <- try(silent = TRUE, check_connection(file_url[1], silent = FALSE))
       if(is.null(check_con) | isFALSE(check_con)){ return(invisible(NULL)) }
     }
 
@@ -131,8 +187,11 @@ download_gpkg <- function(file_url, progress_bar = showProgress){
                    ), silent = TRUE)
       }
 
+    # if anything fails, return NULL
+    if (any(!file.exists(temps) | file.info(temps)$size == 0)) { return(invisible(NULL)) }
+
     # load gpkg to memory
-    temp_sf <- load_gpkg(file_url, temps)
+    temp_sf <- load_gpkg(temps)
     return(temp_sf)
     }
 
@@ -140,51 +199,63 @@ download_gpkg <- function(file_url, progress_bar = showProgress){
 
   else if(length(file_url) > 1) {
 
-    # input for progress bar
-    total <- length(file_url)
-    if(isTRUE(progress_bar)){
-      pb <- utils::txtProgressBar(min = 0, max = total, style = 3)
+    # location of all temp_files
+    temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(file_url,"/"),tail,n=1L)))
+
+    # count number of files that have NOT been downloaded already
+    number_of_files <- sum( (!file.exists(temps) | file.info(temps)$size == 0) )
+
+    # IF there is any file to download, then download them
+    if ( number_of_files > 0 ){
+
+      # test connection with server1
+      try(silent = TRUE,
+          check_con <- check_connection(file_url[1], silent = TRUE)
+          )
+
+      # if server1 fails, replace url and test connection with server2
+      if (is.null(check_con) | isFALSE(check_con)) {
+        file_url <- file_url2
+        check_con <- try(silent = TRUE, check_connection(file_url[1], silent = FALSE))
+        if(is.null(check_con) | isFALSE(check_con)){ return(invisible(NULL)) }
       }
 
+      # input for progress bar
+      if(isTRUE(progress_bar)){
+        pb <- utils::txtProgressBar(min = 0, max = number_of_files, style = 3)
+        }
 
-    # test connection with server1
-    check_con <- check_connection(file_url[1])
+      # download files
+      lapply(X=file_url, function(x){
 
-    # if server1 fails, replace url and test connection with server2
-    if (is.null(check_con) | isFALSE(check_con)) {
-      file_url <- file_url2
-      check_con <- check_connection(file_url[1])
-      if(is.null(check_con) | isFALSE(check_con)){ return(invisible(NULL)) }
-    }
+        # get location of temp_file
+        temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(x,"/"),tail,n=1L)))
 
-    # download files
-    lapply(X=file_url, function(x){
+        # check if file has not been downloaded already. If not, download it
+        if (!file.exists(temps) | file.info(temps)$size == 0) {
+          i <- match(c(x),file_url)
+          try( httr::GET(url=x, #httr::progress(),
+                         httr::write_disk(temps, overwrite = T),
+                         config = httr::config(ssl_verifypeer = FALSE)
+          ), silent = TRUE)
 
-      # location of temp_file
-      temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(x,"/"),tail,n=1L)))
-
-      # check if file has not been downloaded already. If not, download it
-      if (!file.exists(temps) | file.info(temps)$size == 0) {
-                                i <- match(c(x),file_url)
-                                try( httr::GET(url=x, #httr::progress(),
-                                          httr::write_disk(temps, overwrite = T),
-                                          config = httr::config(ssl_verifypeer = FALSE)
-                                          ), silent = TRUE)
-
-                                if(isTRUE(progress_bar)){ utils::setTxtProgressBar(pb, i) }
-                                }
+          if(isTRUE(progress_bar)){ utils::setTxtProgressBar(pb, i) }
+        }
       })
 
-    # closing progress bar
-    if(isTRUE(progress_bar)){close(pb)}
-
-    # load gpkg
-    temp_sf <- load_gpkg(file_url)
-    return(temp_sf)
-
-
+      # closing progress bar
+      if(isTRUE(progress_bar)){close(pb)}
     }
 
+    # if anything fails, return NULL
+    temps <- paste0(tempdir(),"/", unlist(lapply(strsplit(file_url,"/"),tail,n=1L)))
+    if (any(!file.exists(temps) | file.info(temps)$size == 0)) { return(invisible(NULL)) }
+
+    # load gpkg
+    temp_sf <- load_gpkg(temps) #
+    return(temp_sf)
+
+    }
 }
 
 
@@ -195,34 +266,43 @@ download_gpkg <- function(file_url, progress_bar = showProgress){
 
 #' Load geopackage from tempdir to global environment
 #'
-#'
-#' @param file_url A string with the file_url address of a geobr dataset
 #' @param temps The address of a gpkg file stored in tempdir. Defaults to NULL
 #' @keywords internal
 #'
-load_gpkg <- function(file_url, temps=NULL){
+load_gpkg <- function(temps=NULL){
 
   ### one single file
 
-  if(length(file_url)==1){
+  if (length(temps)==1) {
 
     # read sf
-    temp_sf <- sf::st_read(temps, quiet=T)
-    return(temp_sf)
+    temp_sf <- sf::st_read(temps, quiet=TRUE)
   }
 
-  else if(length(file_url) > 1){
+  else if(length(temps) > 1){
 
     # read files and pile them up
-    files <- unlist(lapply(strsplit(file_url,"/"), tail, n = 1L))
-    files <- paste0(tempdir(),"/",files)
-    files <- lapply(X=files, FUN= sf::st_read, quiet=T)
+    files <- lapply(X=temps, FUN= sf::st_read, quiet=TRUE)
     temp_sf <- sf::st_as_sf(data.table::rbindlist(files, fill = TRUE)) # do.call('rbind', files)
-    return(temp_sf)
+
+    # closes issue 284
+    col1 <- names(temp_sf)[1]
+    temp_sf <- subset(temp_sf, get(col1) != 'data_table_sf_bug')
+
+    # remove data.table from object class. Closes #279.
+    class(temp_sf) <- c("sf", "data.frame")
+
   }
 
+  # check if data was read Ok
+  if (nrow(temp_sf)==0) {
+    message("A file must have been corrupted during download. Please restart your R session and download the data again.")
+    return(invisible(NULL))
+  }
+  return(temp_sf)
+
   # load gpkg to memory
-  temp_sf <- load_gpkg(file_url, temps)
+  temp_sf <- load_gpkg(temps)
   return(temp_sf)
 }
 
@@ -242,7 +322,8 @@ load_gpkg <- function(file_url, temps=NULL){
 #'
 #' @keywords internal
 #'
-check_connection <- function(url = 'https://www.ipea.gov.br/geobr/metadata/metadata_gpkg.csv', silent = FALSE){ # nocov start
+check_connection <- function(url = 'https://www.ipea.gov.br/geobr/metadata/metadata_gpkg.csv',
+                             silent = FALSE){ # nocov start
 
   # url <- 'https://google.com/'               # ok
   # url <- 'https://www.google.com:81/'   # timeout
