@@ -7,12 +7,6 @@ knitr::opts_chunk$set(
 )
 
 
-use_suggested_pkgs <- c((requireNamespace("dplyr")), 
-                        (requireNamespace("scales")), 
-                        (requireNamespace("ggplot2")), 
-                        (requireNamespace("censobr")))
-
-use_suggested_pkgs <- all(use_suggested_pkgs)
 
 ## ----eval=FALSE, message=FALSE, warning=FALSE---------------------------------
 #  # From CRAN
@@ -23,20 +17,20 @@ use_suggested_pkgs <- all(use_suggested_pkgs)
 #  devtools::install_github("ipeaGIT/geobr", subdir = "r-package")
 #  
 
-## ----eval=use_suggested_pkgs, message=FALSE, warning=FALSE, results='hide'----
+## ----message=FALSE, warning=FALSE, results='hide'-----------------------------
 library(geobr)
 library(ggplot2)
 library(sf)
 library(dplyr)
 
-## ----eval=use_suggested_pkgs, message=FALSE, warning=FALSE--------------------
+## ----message=FALSE, warning=FALSE---------------------------------------------
 # Available data sets
 datasets <- list_geobr()
 
 head(datasets)
 
 
-## ----eval=use_suggested_pkgs, message=FALSE, warning=FALSE--------------------
+## ----message=FALSE, warning=FALSE---------------------------------------------
 # State of Sergige
 state <- read_state(
   code_state="SE",
@@ -55,7 +49,7 @@ ggplot() +
   geom_sf(data = muni, color=NA, fill = '#1ba185') +
   theme_void()
 
-## ----eval=TRUE, message=FALSE, warning=FALSE, results='hide'------------------
+## ----message=FALSE, warning=FALSE, results='hide'-----------------------------
 # All municipalities in the state of Minas Gerais
 muni <- read_municipality(code_muni = "MG", 
                           year = 2007,
@@ -70,7 +64,7 @@ cntr <- read_census_tract(
 
 head(muni)
 
-## ----eval=TRUE, message=FALSE, warning=FALSE----------------------------------
+## ----message=FALSE, warning=FALSE---------------------------------------------
 # read all intermediate regions
 inter <- read_intermediate_region(
   year = 2017,
@@ -85,7 +79,7 @@ states <- read_state(
 
 head(states)
 
-## ----eval=use_suggested_pkgs, message=FALSE, warning=FALSE, fig.height = 8, fig.width = 8, fig.align = "center"----
+## ----message=FALSE, warning=FALSE, fig.height = 8, fig.width = 8, fig.align = "center"----
 # Remove plot axis
 no_axis <- theme(axis.title=element_blank(),
                  axis.text=element_blank(),
@@ -99,7 +93,7 @@ ggplot() +
   no_axis
 
 
-## ----eval=use_suggested_pkgs, message=FALSE, warning=FALSE, fig.height = 8, fig.width = 8, fig.align = "center"----
+## ----message=FALSE, warning=FALSE, fig.height = 8, fig.width = 8, fig.align = "center"----
 
 # Download all municipalities of Rio
 all_muni <- read_municipality(
@@ -116,7 +110,7 @@ ggplot() +
   no_axis
 
 
-## ----eval=use_suggested_pkgs, message=FALSE, warning=FALSE, results='hide'----
+## ----message=FALSE, warning=FALSE, results='hide'-----------------------------
 # Read data.frame with life expectancy data
 df <- utils::read.csv(system.file("extdata/br_states_lifexpect2017.csv", package = "geobr"), encoding = "UTF-8")
 
@@ -127,7 +121,7 @@ df$uf <- tolower(df$uf)
 states <- dplyr::left_join(states, df, by = c("name_state" = "uf"))
 
 
-## ----eval=use_suggested_pkgs, message=FALSE, warning=FALSE, fig.height = 8, fig.width = 8, fig.align = "center"----
+## ----message=FALSE, warning=FALSE, fig.height = 8, fig.width = 8, fig.align = "center"----
 ggplot() +
   geom_sf(data=states, aes(fill=ESPVIDA2017), color= NA, size=.15) +
     labs(subtitle="Life Expectancy at birth, Brazilian States, 2014", size=8) +
@@ -136,14 +130,14 @@ ggplot() +
     no_axis
 
 
-## ----eval = use_suggested_pkgs------------------------------------------------
+## -----------------------------------------------------------------------------
 library(censobr)
 
 hs <- read_households(year = 2010, 
                       showProgress = FALSE)
 
 
-## ----eval = use_suggested_pkgs, warning = FALSE-------------------------------
+## ----warning = FALSE----------------------------------------------------------
 esg <- hs |> 
         collect() |>
         group_by(code_muni) |>                                             # (a)
@@ -154,7 +148,7 @@ esg <- hs |>
 
 head(esg)
 
-## ----eval = use_suggested_pkgs, warning = FALSE-------------------------------
+## ----warning = FALSE----------------------------------------------------------
 # download municipality geometries
 muni_sf <- geobr::read_municipality(year = 2010,
                                     showProgress = FALSE)
